@@ -22,7 +22,7 @@ from tornado import gen
 
 from ..config import config
 from ..diagnostics.progress_stream import progress_quads, nbytes_bar
-from ..diagnostics import profile
+from .. import profile
 from ..utils import log_errors
 
 if config.get('bokeh-export-tool', False):
@@ -80,7 +80,7 @@ class TaskStream(DashboardComponent):
         self.root = figure(
             title="Task Stream", id='bk-task-stream-plot',
             x_range=x_range, y_range=y_range, toolbar_location="above",
-            x_axis_type='datetime', min_border_right=35, **kwargs)
+            x_axis_type='datetime', min_border_right=35, tools='', **kwargs)
         self.root.yaxis.axis_label = 'Worker Core'
 
         rect = self.root.rect(source=self.source, x="start", y="y",
