@@ -9,7 +9,7 @@ from toolz import first
 from tornado import gen
 from tornado.httpclient import AsyncHTTPClient
 
-from distributed.client import _wait
+from distributed.client import wait
 from distributed.metrics import time
 from distributed.utils_test import gen_cluster, inc, dec, slowinc
 from distributed.bokeh.worker import Counters, BokehWorker
@@ -106,7 +106,7 @@ def test_task_stream(c, s, a, b):
 
     futures = c.map(slowinc, range(10), delay=0.001)
 
-    yield _wait(futures)
+    yield wait(futures)
 
     ts.update()
     d = dict(ts.source.data)
@@ -119,7 +119,7 @@ def test_task_stream(c, s, a, b):
     assert all(len(L) == 10 for L in d.values())
 
     total = c.submit(sum, futures)
-    yield _wait(total)
+    yield wait(total)
 
     ts.update()
     d = dict(ts.source.data)
@@ -130,7 +130,7 @@ def test_task_stream(c, s, a, b):
 def test_task_stream_n_rectangles(c, s, a, b):
     ts = TaskStream(s, n_rectangles=10)
     futures = c.map(slowinc, range(10), delay=0.001)
-    yield _wait(futures)
+    yield wait(futures)
     ts.update()
 
     assert len(ts.source.data['start']) == 10
@@ -141,7 +141,7 @@ def test_task_stream_second_plugin(c, s, a, b):
     ts = TaskStream(s, n_rectangles=10, clear_interval=10)
     ts.update()
     futures = c.map(inc, range(10))
-    yield _wait(futures)
+    yield wait(futures)
     ts.update()
 
     ts2 = TaskStream(s, n_rectangles=5, clear_interval=10)
@@ -152,10 +152,10 @@ def test_task_stream_second_plugin(c, s, a, b):
 def test_task_stream_clear_interval(c, s, a, b):
     ts = TaskStream(s, clear_interval=200)
 
-    yield _wait(c.map(inc, range(10)))
+    yield wait(c.map(inc, range(10)))
     ts.update()
     yield gen.sleep(0.010)
-    yield _wait(c.map(dec, range(10)))
+    yield wait(c.map(dec, range(10)))
     ts.update()
 
     assert len(set(map(len, ts.source.data.values()))) == 1
@@ -163,7 +163,7 @@ def test_task_stream_clear_interval(c, s, a, b):
     assert ts.source.data['name'].count('dec') == 10
 
     yield gen.sleep(0.300)
-    yield _wait(c.map(inc, range(10, 20)))
+    yield wait(c.map(inc, range(10, 20)))
     ts.update()
 
     assert len(set(map(len, ts.source.data.values()))) == 1
@@ -176,7 +176,7 @@ def test_TaskProgress(c, s, a, b):
     tp = TaskProgress(s)
 
     futures = c.map(slowinc, range(10), delay=0.001)
-    yield _wait(futures)
+    yield wait(futures)
 
     tp.update()
     d = dict(tp.source.data)
@@ -184,7 +184,7 @@ def test_TaskProgress(c, s, a, b):
     assert d['name'] == ['slowinc']
 
     futures2 = c.map(dec, range(5))
-    yield _wait(futures2)
+    yield wait(futures2)
 
     tp.update()
     d = dict(tp.source.data)
@@ -206,7 +206,7 @@ def test_TaskProgress_empty(c, s, a, b):
     tp.update()
 
     futures = [c.submit(inc, i, key='f-' + 'a' * i) for i in range(20)]
-    yield _wait(futures)
+    yield wait(futures)
     tp.update()
 
     del futures
@@ -222,7 +222,7 @@ def test_MemoryUse(c, s, a, b):
     mu = MemoryUse(s)
 
     futures = c.map(slowinc, range(10), delay=0.001)
-    yield _wait(futures)
+    yield wait(futures)
 
     mu.update()
     d = dict(mu.source.data)
@@ -235,7 +235,7 @@ def test_CurrentLoad(c, s, a, b):
     cl = CurrentLoad(s)
 
     futures = c.map(slowinc, range(10), delay=0.001)
-    yield _wait(futures)
+    yield wait(futures)
 
     cl.update()
     d = dict(cl.source.data)
@@ -264,7 +264,7 @@ def test_NBytesHistogram(c, s, a, b):
     assert (nh.source.data['top'] != 0).sum() == 1
 
     futures = c.map(inc, range(10))
-    yield _wait(futures)
+    yield wait(futures)
 
     nh.update()
     assert nh.source.data['right'][-1] > 5 * 20
