@@ -2,7 +2,6 @@ from __future__ import print_function, division, absolute_import
 
 from functools import partial
 import os
-import ssl
 import sys
 import threading
 
@@ -11,14 +10,15 @@ import pytest
 from tornado import gen, ioloop, queues
 from tornado.concurrent import Future
 
-from distributed.core import pingpong
 from distributed.metrics import time
 from distributed.utils import get_ip, get_ipv6
-from distributed.utils_test import (slow, loop, gen_test, gen_cluster,
-                                    requires_ipv6, has_ipv6, get_cert)
+from distributed.utils_test import (gen_test, requires_ipv6, has_ipv6,
+                                    get_cert, get_server_ssl_context,
+                                    get_client_ssl_context)
+from distributed.utils_test import loop  # flake8: noqa
 
-from distributed.protocol import (loads, dumps,
-                                  to_serialize, Serialized, serialize, deserialize)
+from distributed.protocol import (to_serialize, Serialized, serialize,
+                                  deserialize)
 
 from distributed.comm import (tcp, inproc, connect, listen, CommClosedError,
                               parse_address, parse_host_port,
@@ -39,7 +39,8 @@ cert_subject = (
     (('localityName', 'Dask-distributed'),),
     (('organizationName', 'Dask'),),
     (('commonName', 'localhost'),)
-    )
+)
+
 
 def check_tls_extra(info):
     assert isinstance(info, dict)
@@ -52,20 +53,37 @@ def check_tls_extra(info):
     assert secret_bits >= 128
 
 
-def get_server_ssl_context(certfile='tls-cert.pem', keyfile='tls-key.pem'):
-    ctx = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH, cafile=ca_file)
-    ctx.check_hostname = False
-    ctx.verify_mode = ssl.CERT_REQUIRED
-    ctx.load_cert_chain(get_cert(certfile), get_cert(keyfile))
-    return ctx
+tls_kwargs = dict(listen_args={'ssl_context': get_server_ssl_context()},
+                  connect_args={'ssl_context': get_client_ssl_context()})
 
-def get_client_ssl_context(certfile='tls-cert.pem', keyfile='tls-key.pem'):
-    ctx = ssl.create_default_context(ssl.Purpose.SERVER_AUTH, cafile=ca_file)
-    ctx.check_hostname = False
-    ctx.verify_mode = ssl.CERT_REQUIRED
-    ctx.load_cert_chain(get_cert(certfile), get_cert(keyfile))
-    return ctx
 
+@gen.coroutine
+def get_comm_pair(listen_addr, listen_args=None, connect_args=None):
+    q = queues.Queue()
+
+    def handle_comm(comm):
+        q.put(comm)
+
+    listener = listen(listen_addr, handle_comm,
+                      connection_args=listen_args)
+    listener.start()
+
+    comm = yield connect(listener.contact_address,
+                         connection_args=connect_args)
+    serv_comm = yield q.get()
+    raise gen.Return((comm, serv_comm))
+
+
+def get_tcp_comm_pair():
+    return get_comm_pair('tcp://')
+
+
+def get_tls_comm_pair():
+    return get_comm_pair('tls://', **tls_kwargs)
+
+
+def get_inproc_comm_pair():
+    return get_comm_pair('inproc://')
 
 
 @gen.coroutine
@@ -325,6 +343,7 @@ def check_inproc_specific(run_client):
 def run_coro(func, *args, **kwargs):
     return func(*args, **kwargs)
 
+
 def run_coro_in_thread(func, *args, **kwargs):
     fut = Future()
     main_loop = ioloop.IOLoop.current()
@@ -334,7 +353,7 @@ def run_coro_in_thread(func, *args, **kwargs):
         try:
             res = thread_loop.run_sync(partial(func, *args, **kwargs),
                                        timeout=10)
-        except:
+        except Exception:
             main_loop.add_callback(fut.set_exc_info, sys.exc_info())
         else:
             main_loop.add_callback(fut.set_result, res)
@@ -350,6 +369,7 @@ def run_coro_in_thread(func, *args, **kwargs):
 def test_inproc_specific_same_thread():
     yield check_inproc_specific(run_coro)
 
+
 @gen_test()
 def test_inproc_specific_different_threads():
     yield check_inproc_specific(run_coro_in_thread)
@@ -444,8 +464,10 @@ def tcp_eq(expected_host, expected_port=None):
 
     return checker
 
+
 tls_eq = tcp_eq
 
+
 def inproc_check():
     expected_ip = get_ip()
     expected_pid = os.getpid()
@@ -473,6 +495,7 @@ def test_default_client_server_ipv4():
     yield check_client_server(':3203',
                               tcp_eq('0.0.0.0', 3203), tcp_eq(EXTERNAL_IP4, 3203))
 
+
 @requires_ipv6
 @gen_test()
 def test_default_client_server_ipv6():
@@ -481,6 +504,7 @@ def test_default_client_server_ipv6():
     yield check_client_server('[::]', tcp_eq('::'), tcp_eq(EXTERNAL_IP6))
     yield check_client_server('[::]:3212', tcp_eq('::', 3212), tcp_eq(EXTERNAL_IP6, 3212))
 
+
 @gen_test()
 def test_tcp_client_server_ipv4():
     yield check_client_server('tcp://127.0.0.1', tcp_eq('127.0.0.1'))
@@ -508,23 +532,16 @@ def test_tcp_client_server_ipv6():
 
 @gen_test()
 def test_tls_client_server_ipv4():
-    listen_args = {'ssl_context': get_server_ssl_context()}
-    connect_args = {'ssl_context': get_client_ssl_context()}
-    kwargs = dict(listen_args=listen_args, connect_args=connect_args)
-
-    yield check_client_server('tls://127.0.0.1', tls_eq('127.0.0.1'), **kwargs)
-    yield check_client_server('tls://127.0.0.1:3221', tls_eq('127.0.0.1', 3221), **kwargs)
+    yield check_client_server('tls://127.0.0.1', tls_eq('127.0.0.1'), **tls_kwargs)
+    yield check_client_server('tls://127.0.0.1:3221', tls_eq('127.0.0.1', 3221), **tls_kwargs)
     yield check_client_server('tls://', tls_eq('0.0.0.0'),
-                              tls_eq(EXTERNAL_IP4), **kwargs)
+                              tls_eq(EXTERNAL_IP4), **tls_kwargs)
+
 
 @requires_ipv6
 @gen_test()
 def test_tls_client_server_ipv6():
-    listen_args = {'ssl_context': get_server_ssl_context()}
-    connect_args = {'ssl_context': get_client_ssl_context()}
-    kwargs = dict(listen_args=listen_args, connect_args=connect_args)
-
-    yield check_client_server('tls://[::1]', tls_eq('::1'), **kwargs)
+    yield check_client_server('tls://[::1]', tls_eq('::1'), **tls_kwargs)
 
 
 @gen_test()
@@ -619,14 +636,11 @@ def check_comm_closed_implicit(addr, delay=None, listen_args=None,
 def test_tcp_comm_closed_implicit():
     yield check_comm_closed_implicit('tcp://127.0.0.1')
 
+
 @gen_test()
 def test_tls_comm_closed_implicit():
-    listen_args = {'ssl_context': get_server_ssl_context()}
-    connect_args = {'ssl_context': get_client_ssl_context()}
+    yield check_comm_closed_implicit('tls://127.0.0.1', **tls_kwargs)
 
-    yield check_comm_closed_implicit('tls://127.0.0.1',
-                                     listen_args=listen_args,
-                                     connect_args=connect_args)
 
 @gen_test()
 def test_inproc_comm_closed_implicit():
@@ -664,19 +678,17 @@ def check_comm_closed_explicit(addr, listen_args=None, connect_args=None):
 def test_tcp_comm_closed_explicit():
     yield check_comm_closed_explicit('tcp://127.0.0.1')
 
+
 @gen_test()
 def test_tls_comm_closed_explicit():
-    listen_args = {'ssl_context': get_server_ssl_context()}
-    connect_args = {'ssl_context': get_client_ssl_context()}
+    yield check_comm_closed_explicit('tls://127.0.0.1', **tls_kwargs)
 
-    yield check_comm_closed_explicit('tls://127.0.0.1',
-                                     listen_args=listen_args,
-                                     connect_args=connect_args)
 
 @gen_test()
 def test_inproc_comm_closed_explicit():
     yield check_comm_closed_explicit(inproc.new_address())
 
+
 @gen_test()
 def test_inproc_comm_closed_explicit_2():
     listener_errors = []
@@ -741,6 +753,7 @@ def check_connect_timeout(addr):
 def test_tcp_connect_timeout():
     yield check_connect_timeout('tcp://127.0.0.1:44444')
 
+
 @gen_test()
 def test_inproc_connect_timeout():
     yield check_connect_timeout(inproc.new_address())
@@ -772,6 +785,7 @@ def test_tcp_many_listeners():
     check_many_listeners('tcp://0.0.0.0')
     check_many_listeners('tcp://')
 
+
 @gen_test()
 def test_inproc_many_listeners():
     check_many_listeners('inproc://')
@@ -800,6 +814,7 @@ def check_listener_deserialize(addr, deserialize, in_value, check_out):
     out_value = yield q.get()
     check_out(out_value)
 
+
 @gen.coroutine
 def check_connector_deserialize(addr, deserialize, in_value, check_out):
     q = queues.Queue()
@@ -818,6 +833,7 @@ def check_connector_deserialize(addr, deserialize, in_value, check_out):
     yield comm.close()
     check_out(out_value)
 
+
 @gen.coroutine
 def check_deserialize(addr):
     # Test with Serialize and Serialized objects
@@ -868,7 +884,7 @@ def check_deserialize(addr):
 
     msg = {'op': 'update',
            'x': b'abc',
-           'y': b'def\n' * (2 ** 20),
+           'y': b'def\n' * (3 * 1024 ** 2),  # end size: 12 MB
            }
     msg_orig = msg.copy()
 
@@ -886,12 +902,12 @@ def check_deserialize(addr):
 def test_tcp_deserialize():
     yield check_deserialize('tcp://')
 
+
 @gen_test()
 def test_inproc_deserialize():
     yield check_deserialize('inproc://')
 
 
-
 def _raise_eoferror():
     raise EOFError
 
@@ -917,6 +933,71 @@ def check_deserialize_eoferror(addr):
         with pytest.raises(CommClosedError):
             yield comm.read()
 
+
 @gen_test()
 def test_tcp_deserialize_eoferror():
     yield check_deserialize_eoferror('tcp://')
+
+
+#
+# Test various properties
+#
+
+@gen.coroutine
+def check_repr(a, b):
+    assert 'closed' not in repr(a)
+    assert 'closed' not in repr(b)
+    yield a.close()
+    assert 'closed' in repr(a)
+    yield b.close()
+    assert 'closed' in repr(b)
+
+
+@gen_test()
+def test_tcp_repr():
+    a, b = yield get_tcp_comm_pair()
+    assert a.local_address in repr(b)
+    assert b.local_address in repr(a)
+    yield check_repr(a, b)
+
+
+@gen_test()
+def test_tls_repr():
+    a, b = yield get_tls_comm_pair()
+    assert a.local_address in repr(b)
+    assert b.local_address in repr(a)
+    yield check_repr(a, b)
+
+
+@gen_test()
+def test_inproc_repr():
+    a, b = yield get_inproc_comm_pair()
+    assert a.local_address in repr(b)
+    assert b.local_address in repr(a)
+    yield check_repr(a, b)
+
+
+@gen.coroutine
+def check_addresses(a, b):
+    assert a.peer_address == b.local_address
+    assert a.local_address == b.peer_address
+    a.abort()
+    b.abort()
+
+
+@gen_test()
+def test_tcp_adresses():
+    a, b = yield get_tcp_comm_pair()
+    yield check_addresses(a, b)
+
+
+@gen_test()
+def test_tls_adresses():
+    a, b = yield get_tls_comm_pair()
+    yield check_addresses(a, b)
+
+
+@gen_test()
+def test_inproc_adresses():
+    a, b = yield get_inproc_comm_pair()
+    yield check_addresses(a, b)
