@@ -303,7 +303,7 @@ def test_remote_access(loop):
 def test_memory(loop):
     with LocalCluster(scheduler_port=0, processes=False, silence_logs=False,
                       diagnostics_port=None, loop=loop) as cluster:
-        assert sum(w.memory_limit for w in cluster.workers) < TOTAL_MEMORY * 0.8
+        assert sum(w.memory_limit for w in cluster.workers) <= TOTAL_MEMORY
 
 
 def test_memory_nanny(loop):
@@ -312,7 +312,7 @@ def test_memory_nanny(loop):
         with Client(cluster.scheduler_address, loop=loop) as c:
             info = c.scheduler_info()
             assert (sum(w['memory_limit'] for w in info['workers'].values())
-                    < TOTAL_MEMORY * 0.9)
+                    <= TOTAL_MEMORY)
 
 
 def test_death_timeout_raises(loop):
@@ -321,3 +321,20 @@ def test_death_timeout_raises(loop):
                           death_timeout=1e-10, diagnostics_port=None,
                           loop=loop) as cluster:
             pass
+
+
+@pytest.mark.parametrize('processes', [True, False])
+def test_diagnostics_available_at_localhost(loop, processes):
+    import requests
+    import random
+    for i in range(3):
+        port = random.randint(10000, 60000)
+        try:
+            with LocalCluster(2, scheduler_port=0, processes=processes,
+                              silence_logs=False, diagnostics_port=port, loop=loop) as c:
+                requests.get('http://localhost:%d/status/' % port, timeout=1)
+                requests.get('http://127.0.0.1:%d/status/' % port, timeout=1)
+        except OSError:
+            pass
+        else:
+            break
