@@ -1,17 +1,14 @@
 from __future__ import print_function, division, absolute_import
 
-import json
 import logging
 import os
 import socket
 
-from toolz import first
 from tornado import web, gen
 from tornado.httpclient import AsyncHTTPClient
 from tornado.httpserver import HTTPServer
 
 from .. import metrics
-from ..utils import log_errors
 from ..comm.utils import get_tcp_server_address
 
 
@@ -44,13 +41,14 @@ def resource_collect(pid=None):
     return {'cpu_percent': psutil.cpu_percent(),
             'status': p.status(),
             'memory_percent': p.memory_percent(),
-            'memory_info_ex': p.memory_info_ex(),
+            'memory_info': p.memory_info(),
             'disk_io_counters': metrics.disk_io_counters(),
             'net_io_counters': metrics.net_io_counters()}
 
 
 class Resources(RequestHandler):
     """Served details about this process and machine"""
+
     def get(self):
         self.write(resource_collect())
 
