@@ -23,6 +23,7 @@ def ensure_string(s):
 
 class Info(RequestHandler):
     """ Basic info about the scheduler """
+
     def get(self):
         self.write({'ncores': self.server.ncores,
                     'status': self.server.status})
@@ -30,6 +31,7 @@ class Info(RequestHandler):
 
 class Processing(RequestHandler):
     """ Active tasks on each worker """
+
     def get(self):
         resp = {addr: [ensure_string(key_split(t)) for t in tasks]
                 for addr, tasks in self.server.processing.items()}
@@ -37,16 +39,23 @@ class Processing(RequestHandler):
 
 
 class Broadcast(RequestHandler):
-    """ Send call to all workers, collate their responses """
+    """
+    Broadcast request to all workers with an HTTP servoce enabled,
+    collate their responses.
+    """
     @gen.coroutine
     def get(self, rest):
-        addresses = [addr.split(':') + [d['services']['http']]
+        """
+        Broadcast request.  *rest* is the path in the HTTP hosts'
+        URL space (e.g. "/foo/bar/somequery?id=5").
+        """
+        addresses = [(addr, (d['host'], d['services']['http']))
                      for addr, d in self.server.worker_info.items()
                      if 'http' in d['services']]
         client = AsyncHTTPClient()
-        responses = {'%s:%s' % (ip, tcp_port): client.fetch("http://%s:%s/%s" %
-                                                  (ip, http_port, rest))
-                     for ip, tcp_port, http_port in addresses}
+        responses = {addr: client.fetch("http://%s:%s/%s" %
+                                        (http_host, http_port, rest))
+                     for addr, (http_host, http_port) in addresses}
         responses2 = yield responses
         responses3 = {k: json.loads(v.body.decode())
                       for k, v in responses2.items()}
@@ -55,13 +64,15 @@ class Broadcast(RequestHandler):
 
 class MemoryLoad(RequestHandler):
     """The total amount of data held in memory by workers"""
+
     def get(self):
         self.write({worker: sum(self.server.nbytes[k] for k in keys)
-                   for worker, keys in self.server.has_what.items()})
+                    for worker, keys in self.server.has_what.items()})
 
 
 class MemoryLoadByKey(RequestHandler):
     """The total amount of data held in memory by workers"""
+
     def get(self):
         out = {}
         for worker, keys in self.server.has_what.items():
@@ -74,6 +85,7 @@ class MemoryLoadByKey(RequestHandler):
 
 class Tasks(RequestHandler):
     """ Lots of information about all the workers """
+
     def get(self):
         with log_errors():
             from ..diagnostics.scheduler import tasks
@@ -82,6 +94,7 @@ class Tasks(RequestHandler):
 
 class Workers(RequestHandler):
     """ Lots of information about all the workers """
+
     def get(self):
         with log_errors():
             from ..diagnostics.scheduler import workers
@@ -99,5 +112,5 @@ def HTTPScheduler(scheduler, **kwargs):
         (r'/workers.json', Workers, {'server': scheduler}),
         (r'/memory-load.json', MemoryLoad, {'server': scheduler}),
         (r'/memory-load-by-key.json', MemoryLoadByKey, {'server': scheduler}),
-        ]), **kwargs)
+    ]), **kwargs)
     return application
