@@ -700,7 +700,7 @@ def test_io_loop(loop):
 
 
 @gen_cluster(client=True)
-def test_transition_story(c, s, a, b):
+def test_story(c, s, a, b):
     x = delayed(inc)(1)
     y = delayed(inc)(x)
     f = c.persist(y)
@@ -708,12 +708,12 @@ def test_transition_story(c, s, a, b):
 
     assert s.transition_log
 
-    story = s.transition_story(x.key)
+    story = s.story(x.key)
     assert all(line in s.transition_log for line in story)
     assert len(story) < len(s.transition_log)
     assert all(x.key == line[0] or x.key in line[-2] for line in story)
 
-    assert len(s.transition_story(x.key, y.key)) > len(story)
+    assert len(s.story(x.key, y.key)) > len(story)
 
 
 @gen_test()
@@ -1153,10 +1153,10 @@ def test_profile_metadata(c, s, a, b):
     yield gen.sleep(0.200)
 
     meta = yield s.get_profile_metadata(profile_cycle_interval=0.100)
-    now = time()
+    now = time() + 1
     assert meta
     assert all(start < t < now for t, count in meta['counts'])
-    assert all(0 < count < 11 for t, count in meta['counts'][:4])
+    assert all(0 <= count < 30 for t, count in meta['counts'][:4])
     assert not meta['counts'][-1][1]
 
 
@@ -1185,3 +1185,10 @@ def test_cancel_fire_and_forget(c, s, a, b):
     yield future.cancel(force=True)
     assert future.status == 'cancelled'
     assert not s.task_state
+
+
+@gen_cluster(client=True, Worker=Nanny)
+def test_log_tasks_during_restart(c, s, a, b):
+    future = c.submit(sys.exit, 0)
+    yield wait(future)
+    assert 'exit' in str(s.events)
